@@ -7,6 +7,7 @@ package Tail::Tool::File;
 # $Revision$, $Source$, $Date$
 
 use Moose;
+use warnings;
 use version;
 use Carp;
 use Data::Dumper qw/Dumper/;
@@ -51,6 +52,7 @@ has size => (
     is            => 'rw',
     isa           => 'Int',
     init_arg      => undef,
+    default       => 0,
     documentation => 'The size of file when last read',
 );
 has pause => (
@@ -154,7 +156,7 @@ sub get_line {
     return if $self->pause;
 
     if ( !$self->remote ) {
-        my $size = -s $self->name;
+        my $size = -s $self->name || 0;
         if ( $size < $self->size ) {
             warn $self->name . " was truncated!\n";
             close $fh;
@@ -229,7 +231,7 @@ sub _get_file_handle {
 
 sub _shell_quote {
     my ($file) = @_;
-    $file =~ s{ ( [^\w\-./] ) }{\\$1}gxms;
+    $file =~ s{ ( [^\w\-./?*] ) }{\\$1}gxms;
 
     return $file;
 }
